--$Id: OneBag.lua 6022 2006-07-28 16:00:17Z kaelten $
Combine = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceHook-2.1", "AceDebug-2.0", "AceConsole-2.0", "AceDB-2.0")
local L = AceLibrary("AceLocale-2.2"):new("Combine")

local months = {"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"}

function Combine:OnInitialize()
    self.colWidth  		= 45
    self.rowHeight 		= 45
    self.topBorder 		= 2
    self.bottomBorder 	= 34
    self.rightBorder    = 10
    self.leftBorder     = 13
    
    self.today =  date("*t")
    self.month = self.today.month
    self.year = self.today.year
    
    self.eventFrame = CombineEventFrame
    self.eventFrame.handler = self
    self.eventFrame:SetBackdropColor(0, 0, 0, .55)
    
    self.frame = CombineCalendarFrame
    self.frame.handler = self
    self.frame:SetBackdropColor(0, 0, 0, .55)
    
    self.frame.days = {}
	self:RegisterChatCommand({"/combine","/com"},{
		type = "execute",
		desc = L["Open the Combine frame"],
		func = function() self.frame:Show() end
	})
end

function Combine:OnEnable()
    self:BuildFrame()
    self:OrganizeFrame()
    self.frame:Show()
    self.eventFrame:Show()
end

function Combine:BuildFrame()
       
    for day = 1, self:GetDaysInMonth(self.month, self.year) do
        if not self.frame.days[day] then
            self.frame.days[day] = CreateFrame("Button", format("%sDay%s", self.frame:GetName(), day), self.frame, "CombineCalendarDayTemplate") 
            self.frame.days[day]:SetID(day)
        end
    end
    
end

function Combine:OrganizeFrame()
    
    local date = date("*t", time({day=1, month=self.month, year=self.year}))
    local curCol = date.wday
    local curRow = 1
    
    for day = 1, 31 do
        if self.frame.days[day] then
            self.frame.days[day]:Hide()
        end
    end
    
    for day = 1, self:GetDaysInMonth(self.month, self.year) do
        self.frame.days[day]:ClearAllPoints()
        self.frame.days[day]:SetPoint("TOPLEFT", self.frame:GetName(), "TOPLEFT", self.leftBorder + (self.colWidth * (curCol - 1)), 0 - self.topBorder - (self.rowHeight * curRow))
        self.frame.days[day]:Show()				
        
        curCol = curCol + 1
        if curCol > 7 then curCol, curRow = 1, curRow + 1 end
        
        if self.today.month == self.month and self.today.year == self.year and self.today.day == day then
            local day = self.frame.days[day]
            day:SetNormalTexture("Interface\\Buttons\\UI-ActionButton-Border")
            day:GetNormalTexture():SetBlendMode("ADD")
            day:GetNormalTexture():SetAlpha(.8)
            day:GetNormalTexture():SetPoint("CENTER", day:GetName(), "CENTER", 0, 1)
            day:GetNormalTexture():SetVertexColor(0, 1, .2)
        else
            local day = self.frame.days[day]
            day:SetNormalTexture("Interface\\AddOns\\OneBag\\BagSlot")
            day:GetNormalTexture():SetBlendMode("BLEND")
            day:GetNormalTexture():SetAlpha(1)
            day:GetNormalTexture():SetPoint("CENTER", day:GetName(), "CENTER", 0, 0)
            day:GetNormalTexture():SetVertexColor(1, 1, 1)
        end
    end
    
    if curCol > 1 then
        curRow = curRow + 1
    end    
    
    self.frame:SetHeight(curRow  * self.rowHeight + self.bottomBorder + self.topBorder) 
	self.frame:SetWidth(7 * self.colWidth + self.leftBorder + self.rightBorder)
    
    getglobal(self.frame:GetName() .. "Date"):SetText(format("%s %s", L[months[self.month]], self.year))
end

function Combine:GetDaysInMonth(month, year)
    if month == 2 and mod(year, 4) == 0 then
        if mod(year,100) == 0 then                
            if mod(year,400) == 0 then                    
                return 29
            end
        else                
            return 29
        end
    end

    if not self.daysInMonth then
        self.daysInMonth = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 }
    end
    
    return self.daysInMonth[month]
end

function Combine:ShowNextMonth()
    self.month = self.month + 1
    if self.month > 12 then 
        self.month = 1
        self.year = self.year + 1
    end
    self:BuildFrame()
    self:OrganizeFrame()
end

function Combine:ShowPrevMonth()
    self.month = self.month - 1
    if self.month < 1 then 
        self.month = 12
        self.year = self.year - 1
    end
    self:BuildFrame()
    self:OrganizeFrame()
end

function Combine:DayOnClick()
	if (self.eventFrame:IsShown()) then
		self.eventFrame:Hide()
	else
		self.eventFrame:Show()
	end
end

function Combine:CreateEvent(day, time, location, duration, minLvl, maxLvl, size, standBy)
	local event = {
		['current'] = {
			['day'] = day,
			['time'] = time,
			['location'] = location,
			['duration'] = duration,
			['minLvl'] = minLvl,
			['maxLvl'] = maxLvl,
			['size'] = size,
			['standBy'] = standBy,
		},
		['history'] = {
			[GetTime()] = {
				['create'] = {day, time, location, duration, minLvl, maxLvl, size, standBy}
			}
		}
	}
end
